<?
/* mymarket.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

function is_logged_in() {
/* this function will return true if the user has logged in.  a user is logged
 * in if the $USER["user"] is set (by the login.php page) and also if the
 * remote IP address matches what we saved in the session ($USER["ip"])
 * from login.php -- this is not a robust or secure check by any means, but it
 * will do for now */

	global $USER;

	return isset($USER["user"])
		&& !empty($USER["user"]["username"])
		&& nvl($USER["ip"]) == $_SERVER["REMOTE_ADDR"];
}

function require_login() {
/* this function checks to see if the user is logged in.  if not, it will show
 * the login screen before allowing the user to continue */

	global $CFG, $USER;

	if (! is_logged_in()) {
		$USER["wantsurl"] = qualified_me();
		redirect("$CFG->wwwroot/login.php");
	}
}

function require_priv($priv) {
/* this function checks to see if the user has the privilege $priv.  if not,
 * it will display an Insufficient Privileges page and stop */

	global $USER;

	if ($USER["user"]["priv"] != $priv) {
		include("$CFG->templatedir/insufficient_privileges.php");
		die;
	}
}

function has_priv($priv) {
/* returns true if the user has the privilege $priv */

	global $USER;

	return $USER["user"]["priv"] == $priv;
}

function build_category_tree(&$output, &$preselected, $parent=1, $indent="") {
/* recursively go through the category tree, starting at a parent, and
 * drill down, printing options for a selection list box.  preselected
 * items are marked as being selected.  this is not an efficient algorithm
 * because it has to issue one query per category!!  it's only used because it
 * is easy to understand.
 */

	$qid = db_query("SELECT id, name FROM categories WHERE parent_id = $parent");

	while ($cat =  db_fetch_object($qid)) {
		$selected = in_array($cat->id, $preselected) ? "selected" : "";
		$output .= "<option value=\"" . ov($cat->id) . "\" $selected>$indent" . ov($cat->name);
		if ($cat->id != $parent) {
			build_category_tree($output, $preselected, $cat->id, $indent."&nbsp;&nbsp;");
		}
	}
}

function load_product($id) {
/* load up the product details for a product with id $id and return it as
 * an object, or false if the object couldn't be loaded (ie. it's not found) */

	$qid = db_query("
	SELECT
		 p.id
		,p.name
		,p.description
		,p.price
		,p.on_special
		,pc.category_id
	FROM
		 products p
		,products_categories pc
	WHERE p.id = pc.product_id
		AND p.id = '$id'
	");

	if ($qid) {
		return db_fetch_object($qid);
	} else {
		return false;
	}
}

function generate_password($maxlen=10) {
/* generate a random password thats thats at most $maxlen characters long
 * by putting 2 vowels after a consenant until into a password until we've
 * reached or surpassed $maxlen.  finally, trim the password and replace
 * one of the characters with a number.  note, we don't include 1 or 0
 * in the number so it doesn't get confused with I or O's
 */

	$C = "bcdfghjkmnpqrstvwxz";
	$V = "aeiouy";
	$totalC = strlen($C)-1;
	$totalV = strlen($V)-1;

	$pw = "";
	while (strlen($pw) < $maxlen) {
		$pw .= substr($C, rand(0, $totalC), 1)
			. substr($V, rand(0, $totalV), 1)
			. substr($V, rand(0, $totalV), 1);
	}

	$pw = substr($pw, 0, $maxlen);
	$pw[rand(0, strlen($pw) - 1)] = rand(2, 9);
	return $pw;
}

function err(&$errorvar) {
/* if $errorvar is set, then print an error marker << */

	if (isset($errorvar)) {
		echo "<font color=#ff0000>&lt;&lt;</font>";
	}
}

function err2(&$errorvar) {
/* like err(), but prints the marker >> */

	if (isset($errorvar)) {
		echo "<font color=#ff0000>&gt;&gt;</font>";
	}
}

function username_exists($username) {
/* returns the true if the username exists */

	$qid = db_query("SELECT 1 FROM users WHERE username = '$username'");
	return db_num_rows($qid);
}

function email_exists($email) {
/* returns true the email address exists */

	$qid = db_query("SELECT 1 FROM users WHERE email = '$email'");
	return db_num_rows($qid);
}

function reset_user_password($username) {
/* resets the password for the user with the username $username, and sends it
 * to him/her via email */

	global $CFG;

	/* load up the user record */
	$qid = db_query("SELECT username, firstname, lastname, email FROM users WHERE username = '$username'");
	$user = db_fetch_object($qid);

	/* reset the password */
	$newpassword = generate_password();
	$qid = db_query("UPDATE users SET password = '" . md5($newpassword) ."' WHERE username = '$username'");

	/* email the user with the new account information */
	$var = new Object;
	$var->username = $user->username;
	$var->fullname = $user->firstname . " " . $user->lastname;
	$var->newpassword = $newpassword;
	$var->support = $CFG->support;

	$emailbody = read_template("$CFG->templatedir/email/reset_password.php", $var);

	mail(
		"$var->fullname <$user->email>",
		"MyMarket Account Information",
		$emailbody,
		"From: $var->support");
}

function get_category_tree($myid=1, $id=1) {
/* returns a tree of the product categories, starting from the top to the
 * category specified by $id */

	global $CFG;

	$qid = db_query("SELECT parent_id, name FROM categories WHERE id = $id");
	if (db_num_rows($qid)) {
		list($parent, $name) = db_fetch_row($qid);
		if ($myid != $id) {
			$name = "<a href='$CFG->wwwroot/shopping?id=$id'>$name</a>";
		}
	} else {
		$parent = 1;
		$name = "";
	}

	if ($parent > 1) {
		return print_category_tree($myid, $parent) . " &gt; " . $name;

	} elseif ($id > 1) {
		return "<a href='$CFG->wwwroot/shopping'>Top</a> &gt; " . $name;

	} elseif ($id == 1) {
		return $id == $myid ? "Top" : "<a href='$CFG->wwwroot/shopping'>Top</a>";
	}
}

function print_category_tree($myid=1, $id=1) {
/* prints the category tree by calling get_category_tree */

	echo get_category_tree($myid, $id);
}

function get_cart_items() {
/* return a $qid of all the items in the shopping cart */

	global $CART;
	$in_clause = $CART->get_productid_list();
	if (empty($in_clause)) {
		return false;
	}

	return db_query("SELECT id, name, price FROM products WHERE id IN ($in_clause)");
}

function chop_ccnum($ccnum) {
/* this function returns the the first and last 4 digits of the credit card number
 * and the expiry date.  it is mainly used when we want to display the credit
 * card number on the screen etc. but we don't want to reveal the whole thing
 */

	return substr($ccnum, 0, 4) . "..." . substr($ccnum, -4);
}

function save_orderinfo(&$frm) {
/* this function saves the order information into the session variable
 * $SESSION["orderinfo"].  it is used in the purchase confirmation stage */

	global $USER;

	$order = new Object();
	$order->customer = $frm["customer"];
	$order->contact = $frm["contact"];
	$order->address = $frm["address"];
	$order->creditcard = $frm["creditcard"];
	$order->expiry = $frm["expiry"];
	$order->comments = $frm["comments"];
	$USER["orderinfo"] = &$order;
}

function load_orderinfo() {
/* this function is the counterpart to save_orderinfo.  it is used to
 * retrieve the order information in the complete order page */

	global $USER;

	if (empty($USER["orderinfo"])) {
		return false;
	} else {
		return $USER["orderinfo"];
	}
}

function clear_orderinfo() {
/* this function is called to clear the orderinfo session variable, it should
 * be used after an order was successfully completed */

	global $USER;

	unset($USER["orderinfo"]);
}

function print_on_specials() {
/* print a list of products that are on special */

	global $CFG;

	$qid = db_query("SELECT id, name, description, price FROM products WHERE on_special = 1");
	include("$CFG->templatedir/on_special.php");
}

function get_sponsor($category = 0) {
/* returns a link/graphic pointing to a sponsor, for inclusion in the headers
 * this function should be smart enough to take a category and load up sponsors
 * who paid for ad space when people are in a particular category. category
 * 0 (the default) means we are not browsing in any category, so showing any
 * sponsor would be okay.
 *
 * TODO: this needs to be implemented
 */

	global $CFG;

	$sponsor_url = "javascript: alert('Go to sponsor page');";
	$sponsor_pic = "banner1.gif";
	$sponsor_alt = "Advertise with MyMarket";

	return "<a href=\"$sponsor_url\"><img src=\"$CFG->bannerdir/$sponsor_pic\" width=468 height=60 border=2 alt=\"$sponsor_alt\"></a>";
}

function print_price($price) {
/* print price, with currency in the proper place */

	global $CFG;

	if ($CFG->currencyfirst) {
		printf("$CFG->currency %.2f", $price);
	} else {
		printf("%.2f, $CFG->currency", $price);
	}
}
?>
